<?php

return array(
    'system_configurator'         => array(
        'admin_email' => array(
            'label'           => 'Administrator`s email',
            'callback'        => 'input',
            'callbck_options' => array(),
        ),
        'email_from'  => array(
            'label'           => 'Email from',
            'callback'        => 'input',
            'callbck_options' => array(),
        ),
    ),
    'ciext_parser_alias_callback' => array(
        'safe_mailto'  => array(get_instance()->load->library('ciext/parser/parser_safe_mailto'), 'parse'),
        'date'         => array(get_instance()->load->library('ciext/parser/parser_date'), 'parse'),
        'configurator' => array(get_instance()->load->library('ciext/parser/parser_configurator'), 'parse'),
    )
);
